@@ -160,6 +160,15 @@ def linker():
 	)
 
 
+# reecriture en variables
+def _var_name(name):
+	name = unidecode.unidecode(name).lower()
+	name = re.sub(r"'", "", name)
+	name = re.sub(r",", "", name)
+	name = re.sub(r"[^a-zA-Z0-9]", "_", name)
+	return name
+
+
 def _name(name):
 	name = unidecode.unidecode(name).lower()
 	name = re.sub(r"[^a-zA-Z0-9]", "", name)
@@ -181,9 +190,6 @@ def display_card():
 		from . import build_library
 		cartes = build_library.build()
 
-	for carte in cartes:
-		library[list(carte)[0]] = carte[list(carte)[0]]
-
 	def card(name, display_name=None):
 		return flask.Markup(
 			"""<span class="card" onclick="dC('{scryfallId}')" onmouseover="hC('{scryfallId}')" onmouseout="oC()">{name}</span>""".format(
@@ -212,4 +218,10 @@ def display_card():
 			)
 		)
 
+	for carte in cartes:
+		# Enabling card names checks
+		library[list(carte)[0]] = carte[list(carte)[0]]
+		# Adding card to context
+		BASE_CONTEXT[_var_name(library[list(carte)[0]]['name'])] = card(library[list(carte)[0]]['name'])
+
 	return dict(card=card, card_image=card_image)
